package model

import (
	"context"
	"icloudapp.cn/tools/entity"
	"icloudapp.cn/tools/service"
	sEntity "icloudapp.cn/tools/service/entity"
)

type MMaterial struct {
	ctx context.Context
}

func NewMMaterial(ctx context.Context) *MMaterial {
	return &MMaterial{
		ctx: ctx,
	}
}

func (m *MMaterial) Add(material *sEntity.Material) (*sEntity.Material, error) {
	material, err := service.NewMaterial(m.ctx).Add(material)
	if err != nil {
		return nil, err
	}
	return material, nil
}

func (m *MMaterial) Materials(uid int64) *entity.MaterialsApi {
	materials := service.NewMaterial(m.ctx).Materials(uid)

	body := make([]entity.MaterialsApiData, 0)

	if len(materials) == 0 {
		return &entity.MaterialsApi{Code: entity.CodeDataDoesNotExist, Msg: "未找到相关数据", Body: map[string][]entity.MaterialsApiData{
			"items": {},
		}}
	}
	for _, val := range materials {
		var material entity.MaterialsApiData
		material.ID = val.ID
		material.Uid = val.UID
		material.FileName = val.Name
		material.Path = val.File
		material.ImageType = val.Type
		body = append(body, material)
	}
	return &entity.MaterialsApi{Code: entity.CodeDataDoesNotExist, Msg: "success", Body: map[string][]entity.MaterialsApiData{
		"items": body,
	}}
}
